# Provider MVC Example App

## BG Color App

The app contains 3 sliders each one represent a primary color (Red/Green/Blue) and every time a slider value changed the background color should reflect the sliders colors merge. Also the app has a reset fab.

![image](asset/bg_color.gif)

### Getting Started

For web running use: flutter run -d chrome

### Code

#### **Controller** class definition:

File(_slider_controller.dart_)

```
import 'package:provider_mvc/controller.dart';

class SliderController extends Controller {
  int _value = 0;

  SliderController(String tag) : super(tag: tag);

  set value(int v) {
    _value = v;
    refresh();
  }

  int get value => _value;
}
```

File(_home_controller.dart_)

```
import 'package:flutter/material.dart';
import 'package:provider_mvc/controller.dart';

class HomeController extends Controller {
  Color _bg = Colors.black;

  set bg(Color c) {
    _bg = c;
    refresh();
  }

  Color get bg => _bg;
}
```

#### **View** class definition.

File(_slider_view.dart_)

```
import 'package:flutter/material.dart';
import '../controller/slider_controller.dart';
import '../controller/home_controller.dart';
import 'package:provider_mvc/controller.dart';
import 'package:provider_mvc/view.dart';

class SliderView extends View<SliderController> {
  final Color _color;

  SliderView(this._color);

  @override
  Widget builder(
      BuildContext context, SliderController controller, Widget widget) {
    return Slider(
      activeColor: _color,
      value: controller.value.toDouble(),
      min: 0,
      max: 255,
      divisions: 256,
      label: '${controller.value}',
      onChanged: (value) {
        controller.value = value.toInt();
        Controller.of<HomeController>().single.bg = Color.fromARGB(
            255,
            Controller.find<SliderController>('RED').single.value,
            Controller.find<SliderController>('GREEN').single.value,
            Controller.find<SliderController>('BLUE').single.value);
      },
    );
  }

  @override
  SliderController create(BuildContext context) {
    String tag;

    if (_color == Colors.red) tag = 'RED';
    if (_color == Colors.green) tag = 'GREEN';
    if (_color == Colors.blue) tag = 'BLUE';

    if (tag == null) throw Exception('Only RED/GREEN/BLUE colors allowed!');

    return Controller.put<SliderController>(SliderController(tag));
  }
}
```

File(_home_screen.dart_)

```
import 'package:flutter/material.dart';
import '../controller/slider_controller.dart';
import '../controller/home_controller.dart';
import 'package:provider_mvc/controller.dart';
import 'package:provider_mvc/view.dart';

import '../view/slider_view.dart';

class HomeScreen extends View<HomeController> {
  @override
  Widget builder(
      BuildContext context, HomeController controller, Widget widget) {
    return Scaffold(
      backgroundColor: controller.bg,
      body: Center(
        child: Column(
          mainAxisAlignment: MainAxisAlignment.center,
          children: [
            SliderView(Colors.red),
            SliderView(Colors.green),
            SliderView(Colors.blue),
          ],
        ),
      ),
      floatingActionButton: FloatingActionButton(
        onPressed: () {
          Controller.of<SliderController>().forEach((ctrl) => ctrl.value = 0);
          controller.bg = Colors.black;
        },
        child: Icon(Icons.refresh),
      ),
    );
  }

  @override
  HomeController create(BuildContext context) =>
      Controller.put<HomeController>(HomeController());
}
```

#### The main class.

File(_main.dart_)

```
import 'package:flutter/material.dart';
import 'view/home_screen.dart';

void main() => runApp(MainApp());

class MainApp extends StatelessWidget {
  @override
  Widget build(BuildContext context) => MaterialApp(
        home: HomeScreen(),
        debugShowCheckedModeBanner: false,
      );
}
```
